#ifndef CONFIGURATION_H
#define CONFIGURATION_H

#include "Tools.h"

//----------------------------------------------------------------------------
class Configuration
{
    SINGLETON_OBJECT(Configuration);

  public:
    //------------------------------------------------------------------------
    Configuration();
    ~Configuration();

    //------------------------------------------------------------------------
    void searchDataDir();

    //------------------------------------------------------------------------
    inline const char *getDataDir() const
    {
        return m_dataDir;
    }

  protected:
    //------------------------------------------------------------------------
    const char *m_dataDir;
};

#endif //CONFIGURATION_H
